@@ -100,9 +100,41 @@ class CollectPaymentSuccessEvent(Event):
         super().__init__("collect_payment_success")
 
 
-class AddSupervisorContextEvent(Event):
-    def __init__(self, context: str):
-        super().__init__("add_supervisor_context", {"context": context})
+class SupervisorRequestEvent(Event):
+    def __init__(self, content: str):
+        super().__init__("supervisor_request", {"content": content})
+
+
+class SupervisorResponseEvent(Event):
+    def __init__(self, content: str):
+        super().__init__("supervisor_response", {"content": content})
+
+
+class ConnectSTSEvent(Event):
+    def __init__(self, configuration: dict):
+        super().__init__("connect_sts", {"configuration": configuration})
+
+
+class DisconnectSTSEvent(Event):
+    def __init__(self):
+        super().__init__("disconnect_sts", {})
+
+
+class UpdateCallEvent(Event):
+    def __init__(self, data: dict):
+        super().__init__("update_call", {"data": data})
+
+
+class StartRecordingEvent(Event):
+    def __init__(self, status_callback_url: str):
+        super().__init__(
+            "start_recording", {"status_callback_url": status_callback_url}
+        )
+
+
+class StopRecordingEvent(Event):
+    def __init__(self):
+        super().__init__("stop_recording", {})
 
 
 def event_to_str(event: Event) -> str:
@@ -131,6 +163,13 @@ def event_from_str(event_str: str) -> Event:
         "warm_transfer": lambda: WarmTransferEvent(data["phone_number"], data["data"]),
         "collect_payment": lambda: CollectPaymentEvent(data["amount"]),
         "collect_payment_success": CollectPaymentSuccessEvent,
+        "supervisor_request": lambda: SupervisorRequestEvent(data["content"]),
+        "supervisor_response": lambda: SupervisorResponseEvent(data["content"]),
+        "connect_sts": lambda: ConnectSTSEvent(data["configuration"]),
+        "disconnect_sts": DisconnectSTSEvent,
+        "update_call": lambda: UpdateCallEvent(data["data"]),
+        "start_recording": lambda: StartRecordingEvent(data["status_callback_url"]),
+        "stop_recording": StopRecordingEvent,
     }
 
     if name in event_types:
